<?php
namespace MascotCoreCrotive\Widgets\Services\Skins;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Css_Filter;
use Elementor\Skin_Base as Elementor_Skin_Base;

use MASCOTCORECROTIVE\Lib;
use MASCOTCORECROTIVE\CPT\Services\CPT_Services;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Skin_Style_Current_Theme5 extends Elementor_Skin_Base {

	protected function _register_controls_actions() {
		add_action( 'elementor/element/tm-ele-cpt-services/general/after_section_end', [ $this, 'register_layout_controls' ] );
		add_action( 'elementor/element/tm-ele-cpt-services/general/after_section_end', [ $this, 'register_background_overlay_controls' ] );
	}

	public function get_id() {
		return 'skin-style-current-theme5';
	}


	public function get_title() {
		return __( 'Skin - Style Current Theme5', 'mascot-core-crotive' );
	}


	public function register_layout_controls( Widget_Base $widget ) {
		$this->parent = $widget;

		$this->start_controls_section(
			'content_wrapper_styling',
			[
				'label' => esc_html__( 'Content Wrapper Styling', 'mascot-core-crotive' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'content_wrapper_color_options',
			[
				'label' => esc_html__( 'BG Color Options', 'mascot-core-crotive' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
			'content_wrapper_custom_bg_color',
			[
				'label' => esc_html__( "Custom Background Color", 'mascot-core-crotive' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-item-current-style5 .inner-box' => 'background-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_custom_bg_color_hover',
			[
				'label' => esc_html__( "Custom Background Color (Hover)", 'mascot-core-crotive' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-item-current-style5 .inner-box:after' => 'background-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_theme_colored',
			[
				'label' => esc_html__( "Make BG Theme Colored", 'mascot-core-crotive' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .service-item-current-style5 .inner-box' => 'background-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_responsive_control(
			'content_wrapper_theme_colored_hover',
			[
				'label' => esc_html__( "Make BG Theme Colored (Hover)", 'mascot-core-crotive' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .service-item-current-style5 .inner-box:after' => 'background-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->end_controls_section();
	}



	public function register_background_overlay_controls() {
		// Background Overlay
		$this->start_controls_section(
			'background_overlay',
			[
				'label' => esc_html__( 'Current Skin Background Overlay', 'mascot-core-crotive' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs( 'tabs_background_overlay' );

		$this->start_controls_tab(
			'tab_background_overlay_normal',
			[
				'label' => esc_html__( 'Normal', 'mascot-core-crotive' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background_overlay',
				'selector' => '{{WRAPPER}} .service-item-current-style5 .inner-box:before',
			]
		);

		$this->add_responsive_control(
			'background_overlay_opacity',
			[
				'label' => esc_html__( 'Opacity', 'mascot-core-crotive' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => .5,
				],
				'range' => [
					'px' => [
						'max' => 1,
						'step' => 0.01,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .service-item-current-style5 .inner-box:before' => 'opacity: {{SIZE}};',
				],
				'condition' => [
					'background_overlay_background' => [ 'classic', 'gradient' ],
				],
			]
		);

		$this->add_group_control(
			Group_Control_Css_Filter::get_type(),
			[
				'name' => 'css_filters',
				'selector' => '{{WRAPPER}} .service-item-current-style5 .inner-box:before',
			]
		);

		$this->add_control(
			'overlay_blend_mode',
			[
				'label' => esc_html__( 'Blend Mode', 'mascot-core-crotive' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => esc_html__( 'Normal', 'mascot-core-crotive' ),
					'multiply' => esc_html__( 'Multiply', 'mascot-core-crotive' ),
					'screen' => esc_html__( 'Screen', 'mascot-core-crotive' ),
					'overlay' => esc_html__( 'Overlay', 'mascot-core-crotive' ),
					'darken' => esc_html__( 'Darken', 'mascot-core-crotive' ),
					'lighten' => esc_html__( 'Lighten', 'mascot-core-crotive' ),
					'color-dodge' => esc_html__( 'Color Dodge', 'mascot-core-crotive' ),
					'saturation' => esc_html__( 'Saturation', 'mascot-core-crotive' ),
					'color' => esc_html__( 'Color', 'mascot-core-crotive' ),
					'luminosity' => esc_html__( 'Luminosity', 'mascot-core-crotive' ),
					'difference' => esc_html__( 'Difference', 'mascot-core-crotive' ),
					'exclusion' => esc_html__( 'Exclusion', 'mascot-core-crotive' ),
					'hue' => esc_html__( 'Hue', 'mascot-core-crotive' ),
				],
				'selectors' => [
					'{{WRAPPER}} .service-item-current-style5 .inner-box:before' => 'mix-blend-mode: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_background_overlay_hover',
			[
				'label' => esc_html__( 'Hover', 'mascot-core-crotive' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background_overlay_hover',
				'selector' => '{{WRAPPER}} .service-item-current-style5:hover .inner-box:before',
			]
		);

		$this->add_responsive_control(
			'background_overlay_hover_opacity',
			[
				'label' => esc_html__( 'Opacity', 'mascot-core-crotive' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => .5,
				],
				'range' => [
					'px' => [
						'max' => 1,
						'step' => 0.01,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .service-item-current-style5:hover .inner-box:before' => 'opacity: {{SIZE}};',
				],
				'condition' => [
					'background_overlay_hover_background' => [ 'classic', 'gradient' ],
				],
			]
		);

		$this->add_group_control(
			Group_Control_Css_Filter::get_type(),
			[
				'name' => 'css_filters_hover',
				'selector' => '{{WRAPPER}} .service-item-current-style5:hover .inner-box:before',
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}



	public function render() {
		$settings = $this->parent->get_settings_for_display();

		$new_cpt_class = CPT_Services::Instance();
		$class_instance =  (array) $new_cpt_class;
		$settings['holder_id'] = crotive_get_isotope_holder_ID('services');

		$settings = $this->parent->sercice_custom_icon_img( $settings );
		$this->render_output( $class_instance, $settings );
	}

	public function render_output( $class_instance, $settings ) {
		$new_cpt_class = $class_instance;

		$settings['the_query'] = $this->parent->query_posts($new_cpt_class);

		//enqueue css
		$direction_suffix = is_rtl() ? '.rtl' : '';
		wp_enqueue_style( 'tm-service-skin-current-theme5', MASCOT_CORE_CROTIVE_URL_PATH . 'assets/css/cpt/services/service-skin-current-theme5' . $direction_suffix . '.css' );

		//classes
		$classes = array();
		if( $settings['add_border_radius'] ) {
			$classes[] = 'border-radius-around-box';
		}
		$settings['classes'] = $classes;

		//button classes
		$settings['btn_classes'] = mascot_core_prepare_button_classes_from_params( $settings );

		//ptTaxKey
		$settings['ptTaxKey'] = $new_cpt_class['ptTaxKey'];

		//Owl Carousel Data
		$settings['owl_carousel_data_info'] = mascot_core_prepare_owlcarousel_data_from_params( $settings );

		$html = mascot_core_crotive_get_cpt_shortcode_template_part( 'services', $settings['display_type'], 'services/tpl', $settings, true );

		echo $html;
	}
}
